@@ -65,7 +65,7 @@ py::object geyser::Core::compose(const std::string &name, py::dict profile) {
         auto key = it.first.cast<std::string>();
         auto value = it.second;
         if (key.size() < 4 || (!(key.substr(0, 2) == "__") && !(key.substr(key.size() - 2, 2) == "__"))) {
-            fill_kwargs(profile, kwargs, key, value);
+            fill_kwargs(item_profile, kwargs, key, value);
         }
     }
     if (context.find(name) != context.end()) {
@@ -80,8 +80,7 @@ py::object geyser::Core::compose(const std::string &name, py::dict profile) {
 }
 
 void geyser::Core::fill_kwargs(py::dict &profile, py::kwargs &kwargs, const std::string &key, pybind11::handle &value) {
-    std::string mirrored_key;
-    mirror_key(key, profile, mirrored_key);
+    std::string mirrored_key = mirror_key(key, profile);
     if (pybind11::isinstance<py::str>(value) && value.cast<py::str>().cast<std::string>() == "__compose__") {
         if (context.find(key) != context.end()) {
             kwargs[py::str(mirrored_key.c_str())] = context.at(key);
@@ -93,14 +92,14 @@ void geyser::Core::fill_kwargs(py::dict &profile, py::kwargs &kwargs, const std:
     }
 }
 
-void geyser::Core::mirror_key(const std::string &key, py::dict &profile, std::string &mirrored_key) const {
+std::string geyser::Core::mirror_key(const std::string &key, py::dict &profile) const {
     py::dict mirrors;
     if (profile[key.c_str()].contains("__mirror__"))
         mirrors = profile[key.c_str()]["__mirror__"].cast<py::dict>();
     if (mirrors.contains(key)) {
-        mirrored_key = mirrors[key.c_str()].cast<py::str>().cast<std::string>();
+        return mirrors[key.c_str()].cast<py::str>().cast<std::string>();
     } else {
-        mirrored_key = key;
+        return key;
     }
 }
 
